"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getIsValidUrl = void 0;
const yup_1 = require("yup");
const decodeAndSanitizeUrl_1 = require("../../../helpers/navigation/decodeAndSanitizeUrl");
const extractDomain_1 = require("../extractDomain");
const getNativeAuthTokenDomain_1 = require("../getNativeAuthTokenDomain");
const getDomain_1 = require("../getDomain");
const getIsValidUrl = ({ value, token }) => {
    if (value == '') {
        return true;
    }
    const url = (0, decodeAndSanitizeUrl_1.decodeAndSanitizeUrl)(value);
    let validUrl;
    try {
        validUrl = Boolean(new URL(url));
    }
    catch {
        validUrl = false;
    }
    const { domain: urlDomain } = (0, extractDomain_1.extractDomain)(url);
    const domain = (0, getDomain_1.getDomain)(urlDomain);
    // use nativeAuthOrigin if defined. If not, fallback on domain
    const nativeAuthTokenDomain = (0, getNativeAuthTokenDomain_1.getNativeAuthTokenDomain)({
        token,
        fallbackDomain: domain
    });
    const sameDomainAsReferrer = domain === urlDomain && domain === nativeAuthTokenDomain;
    const isTestEnvironment = urlDomain?.endsWith('.localhost');
    // allow local debugging
    if (isTestEnvironment) {
        return true;
    }
    // allow VsCode or chromeExtension
    if (url.startsWith('vscode://') ||
        url.startsWith('chrome-extension://') ||
        url.startsWith('moz-extension://')) {
        return true;
    }
    // allow only valid domains
    const isValid = url.startsWith('https://') || url.startsWith('http://');
    if (!isValid) {
        return false;
    }
    // allow only valid Urls
    try {
        const urlValidationSchema = (0, yup_1.string)().url();
        urlValidationSchema.validateSync(url);
    }
    catch (err) {
        return false;
    }
    return validUrl && sameDomainAsReferrer;
};
exports.getIsValidUrl = getIsValidUrl;
//# sourceMappingURL=getIsValidUrl.js.map